@@ -2,7 +2,7 @@
  *
  * client main program
  *
- * $Id: lsh.c,v 1.111 2000/06/01 23:37:55 nisse Exp $ */
+ * $Id: lsh.c,v 1.112 2000/06/04 14:55:44 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -1332,7 +1332,7 @@ do_lsh_default_handler(struct exception_handler *s,
     switch(e->type)
       {
       case EXC_RESOLVE:
-      case EXC_AUTH:
+      case EXC_USERAUTH:
       case EXC_SERVICE:
       case EXC_SEXP_SYNTAX:
       case EXC_SPKI_TYPE:
