@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: parse.c,v 1.26 2000/02/02 22:43:43 nisse Exp $ */
+ * $Id: parse.c,v 1.27 2000/04/23 17:48:50 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -35,15 +35,17 @@
 #include <assert.h>
 #include <string.h>
 
-void simple_buffer_init(struct simple_buffer *buffer,
-			UINT32 capacity, UINT8 *data)
+void
+simple_buffer_init(struct simple_buffer *buffer,
+		   UINT32 capacity, const UINT8 *data)
 {
   buffer->capacity = capacity;
   buffer->pos = 0;
   buffer->data = data;
 }
 
-int parse_uint32(struct simple_buffer *buffer, UINT32 *result)
+int
+parse_uint32(struct simple_buffer *buffer, UINT32 *result)
 {
   if (LEFT < 4)
     return 0;
@@ -53,8 +55,9 @@ int parse_uint32(struct simple_buffer *buffer, UINT32 *result)
   return 1;
 }
 
-int parse_string(struct simple_buffer *buffer,
-		 UINT32 *length, UINT8 **start)
+int
+parse_string(struct simple_buffer *buffer,
+	     UINT32 *length, const UINT8 **start)
 {
   UINT32 l;
 
@@ -70,8 +73,9 @@ int parse_string(struct simple_buffer *buffer,
   return 1;
 }
 
-int parse_octets(struct simple_buffer *buffer,
-		 UINT32 length, UINT8 *start)
+int
+parse_octets(struct simple_buffer *buffer,
+	     UINT32 length, UINT8 *start)
 {
   if (LEFT < length)
     return 0;
@@ -80,10 +84,11 @@ int parse_octets(struct simple_buffer *buffer,
   return 1;
 }
 
-struct lsh_string *parse_string_copy(struct simple_buffer *buffer)
+struct lsh_string *
+parse_string_copy(struct simple_buffer *buffer)
 {
   UINT32 length;
-  UINT8 *start;
+  const UINT8 *start;
   
   if (!parse_string(buffer, &length, &start))
     return NULL;
@@ -92,11 +97,12 @@ struct lsh_string *parse_string_copy(struct simple_buffer *buffer)
 }
 
 /* Initializes subbuffer to parse a string from buffer */
-int parse_sub_buffer(struct simple_buffer *buffer,
-		     struct simple_buffer *subbuffer)
+int
+parse_sub_buffer(struct simple_buffer *buffer,
+		 struct simple_buffer *subbuffer)
 {
   UINT32 length;
-  UINT8 *data;
+  const UINT8 *data;
 
   if (!parse_string(buffer, &length, &data))
     return 0;
@@ -105,7 +111,8 @@ int parse_sub_buffer(struct simple_buffer *buffer,
   return 1;
 }
 
-int parse_uint8(struct simple_buffer *buffer, unsigned *result)
+int
+parse_uint8(struct simple_buffer *buffer, unsigned *result)
 {
   if (!LEFT)
     return 0;
@@ -115,7 +122,8 @@ int parse_uint8(struct simple_buffer *buffer, unsigned *result)
   return 1;
 }
 
-int parse_utf8(struct simple_buffer *buffer, UINT32 *result)
+int
+parse_utf8(struct simple_buffer *buffer, UINT32 *result)
 {
   UINT32 first;
   int length;
@@ -177,7 +185,8 @@ int parse_utf8(struct simple_buffer *buffer, UINT32 *result)
   return 1;
 }  
       
-int parse_boolean(struct simple_buffer *buffer, int *result)
+int
+parse_boolean(struct simple_buffer *buffer, int *result)
 {
   if (!LEFT)
     return 0;
@@ -186,10 +195,11 @@ int parse_boolean(struct simple_buffer *buffer, int *result)
   return 1;
 }
 
-int parse_bignum(struct simple_buffer *buffer, mpz_t result)
+int
+parse_bignum(struct simple_buffer *buffer, mpz_t result)
 {
   UINT32 length;
-  UINT8 *digits;
+  const UINT8 *digits;
 
   if (!parse_string(buffer, &length, &digits))
     return 0;
@@ -199,10 +209,11 @@ int parse_bignum(struct simple_buffer *buffer, mpz_t result)
   return 1;
 }
 
-int parse_atom(struct simple_buffer *buffer, UINT32 *result)
+int
+parse_atom(struct simple_buffer *buffer, UINT32 *result)
 {
   UINT32 length;
-  UINT8 *start;
+  const UINT8 *start;
 
   if ( (!parse_string(buffer, &length, &start))
        || length > 64)
@@ -219,7 +230,8 @@ int parse_atom(struct simple_buffer *buffer, UINT32 *result)
 /* NOTE: This functions record the fact that it has read to the end of
  * the buffer by setting the position to *beyond* the end of the
  * buffer. */
-int parse_next_atom(struct simple_buffer *buffer, UINT32 *result)
+int
+parse_next_atom(struct simple_buffer *buffer, UINT32 *result)
 {
   UINT32 i;
 
@@ -242,7 +254,8 @@ int parse_next_atom(struct simple_buffer *buffer, UINT32 *result)
   return 1;
 }
 
-struct int_list *parse_atoms(struct simple_buffer *buffer, unsigned limit)
+struct int_list *
+parse_atoms(struct simple_buffer *buffer, unsigned limit)
 {
   unsigned count;
   unsigned i;
@@ -279,7 +292,8 @@ struct int_list *parse_atoms(struct simple_buffer *buffer, unsigned limit)
   return res;
 }
 
-struct int_list *parse_atom_list(struct simple_buffer *buffer, unsigned limit)
+struct int_list *
+parse_atom_list(struct simple_buffer *buffer, unsigned limit)
 {
   struct simple_buffer sub_buffer;
 
@@ -290,7 +304,8 @@ struct int_list *parse_atom_list(struct simple_buffer *buffer, unsigned limit)
 }
 
 /* Returns success (i.e. 1) iff there is no data left */
-int parse_eod(struct simple_buffer *buffer)
+int
+parse_eod(struct simple_buffer *buffer)
 {
   return !LEFT;
 }
